@@ -36,6 +36,7 @@ class observation(object):
 
     _gti_start_ = [0]
     _gti_stop_ = [0]
+    _timezero_ = 0
 
 
 class light_curve(observation):
@@ -52,6 +53,7 @@ class light_curve(observation):
 
     def read_from_fits(self, filename):
 
+        self._filename_ = filename
         ff = pf.open(filename)
 
         data_ind = 1
@@ -71,15 +73,30 @@ class light_curve(observation):
 
         self._timeref_ = ff[data_ind].header['TIMEREF']
         self._timesys_ = ff[data_ind].header['TIMESYS']
-        self._mjdref_ = ff[data_ind].header['MJDREF']
+        try:
+            self._mjdref_ = ff[data_ind].header['MJDREF']
+        except:
+            logger.debug("Try to use MJDREFI and MJDREFF")
+            self._mjdref_ = ff[data_ind].header['MJDREFI'] + ff[data_ind].header['MJDREFF']
         self._exposure_ = ff[data_ind].header['EXPOSURE']
 
+        #TODO Use this value
+        self._timepixr_ = ff[data_ind].header['TIMEPIXR']
+
         self._timedel_ = ff[data_ind].header['TIMEDEL']
 
         self._tstart_ = ff[data_ind].header['TSTART']
         self._tstop_ = ff[data_ind].header['TSTOP']
 
-        self._energy_ranges_ = [ff[data_ind].header['CHANMIN'], ff[data_ind].header['CHANMAX']]
+        try:
+            self._energy_ranges_ = [ff[data_ind].header['CHANMIN'], ff[data_ind].header['CHANMAX']]
+        except:
+            logger.info("Energy ranges not available")
+
+        try:
+            self._timezero_ = ff[data_ind].header['TIMEZERO']
+        except:
+            logger.info("TIMEZERO not available")
 
         try:
             self._dtimes_ = ff[data_ind].data['XAX_E']
@@ -88,14 +105,15 @@ class light_curve(observation):
             self._dtimes_ = np.ones(len(self._times_)) * self._timedel_
 
         self._gti_start_ = ff[gti_ind].data['START']
-        self._gti_start_ = ff[gti_ind].data['STOP']
+        self._gti_stop_ = ff[gti_ind].data['STOP']
 
         ff.close()
 
         self.dump_info()
 
     def dump_info(self):
-        logger.info("The light curve has %d bin"%(len(self._times_)))
+        logger.info("The light curve %s has %d bin"%(self._filename_, len(self._times_)))
+        logger.info("The light curve %s has %d GTI bin" % (self._filename_, len(self._gti_start_)))
 
     def from_lc(self, other):
         self._times_ = other._times_
@@ -117,7 +135,7 @@ class light_curve(observation):
         self._energy_ranges_ = other._energy_ranges_
 
         self._gti_start_ = other._gti_start_
-        self._gti_start_ = other._gti_start_
+        self._gti_stop_ = other._gti_stop_
 
         self._data_header_ = other._data_header_
         self._gti_header_ = other._gti_header_
@@ -155,6 +173,8 @@ class light_curve(observation):
 
     def make_rebin_table(self, min_sn, max_time, gti_threshold, min_bin_size, max_point_sn, single_point_check):
         logger.debug("Making a rebin table for min S/N %f" % min_sn )
+        logger.debug("Making a rebin table with GTI threshold %f" % gti_threshold)
+
         table = np.zeros(len(self._times_))
         tt = 0
         rr = 0
@@ -181,8 +201,8 @@ class light_curve(observation):
         n_gti = len(self._gti_start_)
         _size = len(self._times_)
 
-        GTI_START = self._gti_start_
-        GTI_STOP = self._gti_stop_
+        GTI_START = self._gti_start_ - self._timezero_
+        GTI_STOP = self._gti_stop_ - self._timezero_
 
         tot_disregard_time = 0
         for i in range(_size):
@@ -199,10 +219,11 @@ class light_curve(observation):
 
             if n_gti > 1:
                 if _x[i] < GTI_START[0] or _x[i] > GTI_STOP[n_gti - 1]:
+                    logger.debug("Event %d out of GTI" % i)
                     table[i] = -2
                     continue
 
-                if not _x[i] >= GTI_START[curr_gti_ind] and _x[i] <= GTI_STOP[curr_gti_ind]:
+                if not (_x[i] >= GTI_START[curr_gti_ind] and _x[i] <= GTI_STOP[curr_gti_ind]):
                     logger.info("Event # %d time %g not in gti bin %d %g -- %g " % (
                     i, _x[i], curr_gti_ind, GTI_START[curr_gti_ind],
                     GTI_STOP[curr_gti_ind]))
@@ -214,30 +235,30 @@ class light_curve(observation):
                             table[i] = -2
                             continue
 
-                        if curr_gti_ind < n_gti - 1:
+                    if curr_gti_ind < n_gti - 1:
 
-                            if _x[i] < GTI_START[curr_gti_ind + 1] and _x[i] > GTI_STOP[curr_gti_ind]:
-                                table[i] = -2
-                                continue
+                        if _x[i] < GTI_START[curr_gti_ind + 1] and _x[i] > GTI_STOP[curr_gti_ind]:
+                            table[i] = -2
+                            continue
 
-                        # Check if we can continue accumulation despite the GTI break
-                        # char neglect_gti=0;
-                        # gti_flag=1 means stopping accumulation, gti_flag=0 means do not be bothered by the GTI
-                        # to be checked
-                        # removed < GTI_START[curr_gti_ind]
-                        # Rememeber that we are outside the current GTI, so we have gone to the next one
-                        if _x[i] - GTI_STOP[curr_gti_ind] <= gti_threshold:
-                            logger.info("Event does not exceed the GTI gap\n")
-                            gti_flag = 0
-                        else:
-                            logger.info("GTI Threshold exceeded Stop accumulation\n")
-                            gti_flag = 1
+                    # Check if we can continue accumulation despite the GTI break
+                    # char neglect_gti=0;
+                    # gti_flag=1 means stopping accumulation, gti_flag=0 means do not be bothered by the GTI
+                    # to be checked
+                    # removed < GTI_START[curr_gti_ind]
+                    # Rememeber that we are outside the current GTI, so we have gone to the next one
+                    if _x[i] - GTI_STOP[curr_gti_ind] <= gti_threshold:
+                        logger.debug("Event does not exceed the GTI gap\n")
+                        gti_flag = 0
+                    else:
+                        logger.debug("GTI Threshold exceeded Stop accumulation\n")
+                        gti_flag = 1
 
-                            # Increases GTI index
-                            curr_gti_ind += 1
-                            if (curr_gti_ind >= n_gti):
-                                end_flag = 1
-                                curr_gti_ind = n_gti - 1
+                        # Increases GTI index
+                        curr_gti_ind += 1
+                        if (curr_gti_ind >= n_gti):
+                            end_flag = 1
+                            curr_gti_ind = n_gti - 1
             else:
                 # In case no GTI is present
                 delta_t = 0
@@ -250,9 +271,10 @@ class light_curve(observation):
                 else:
                     gti_flag = 0
 
-            if gti_flag:
+            if gti_flag > 0:
                 logger.debug("Entered check for break in GTI exceeded!!")
                 logger.debug("If not enough S/R, disregard all previous bins!!")
+
                 if i == 0:
                     continue
 
